HRU Discretization
******************

HRU Discretization
======================
.. autoclass:: ai4water.preprocessing.spatial_processing.MakeHRUs
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__